Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AADTokenResponse ¶
type AADTokenResponse struct {
AccessToken string `json:"access_token"`
Error string `json:"error"`
ErrorDescription string `json:"error_description"`
}
AADTokenResponse is used to unmarshal responses received from IMDS when retrieving MSI tokens for authentication.
type AzureConfig ¶
type AzureConfig struct {
Cloud string `json:"cloud"`
ClientID string `json:"aadClientId,omitempty"`
ClientSecret string `json:"aadClientSecret,omitempty"`
TenantID string `json:"tenantId,omitempty"`
UserAssignedIdentityID string `json:"userAssignedIdentityID,omitempty"`
}
AzureConfig represents the fields we need from the azure.json file present on all AKS nodes.
type Compute ¶
type Compute struct {
ResourceID string `json:"resourceId,omitempty"`
}
Compute represents the compute-related fields we need from VMSS-related instance data.
type ExecCredential ¶
type ExecCredential struct {
APIVersion string `json:"apiVersion"`
Kind string `json:"kind"`
Spec struct {
Cluster struct {
CertificateAuthorityData string `json:"certificate-authority-data,omitempty"`
Config interface{} `json:"config,omitempty"`
InsecureSkipTLSVerify bool `json:"insecure-skip-tls-verify,omitempty"`
ProxyURL string `json:"proxy-url,omitempty"`
Server string `json:"server,omitempty"`
TLSServerName string `json:"tls-server-name,omitempty"`
} `json:"cluster,omitempty"`
Interactive bool `json:"interactive,omitempty"`
} `json:"spec,omitempty"`
Status ExecCredentialStatus `json:"status,omitempty"`
}
ExecCredential represents cluster-related data supplied to the client plugin by kubelet when invoked for generating bootstrap tokens.
type ExecCredentialStatus ¶
type VMSSAttestedData ¶
type VMSSAttestedData struct {
Encoding string `json:"encoding,omitempty"`
Signature string `json:"signature,omitempty"`
}
VMSSAttestedData represents the fields we need the attested data response retrieved from IMDS.
type VMSSInstanceData ¶
type VMSSInstanceData struct {
Compute Compute `json:"compute,omitempty"`
}
VMSSInstanceData represents the top-level fields we need from VMSS-related instance data retrieved from IMDS.